@@ -27,7 +27,7 @@ class HPOBase(LoggingMixin, metaclass=ABCMeta):
         creator: creator_type,
         params: Dict[str, DataType],
         *,
-        converter: Callable[[List[created_type]], patterns_type] = None,
+        converter: Optional[Callable[[List[created_type]], patterns_type]] = None,
         verbose_level: int = 2,
         **kwargs,
     ):
@@ -101,13 +101,13 @@ class HPOBase(LoggingMixin, metaclass=ABCMeta):
         x: generic_data_type,
         y: generic_data_type,
         estimators: List[Estimator],
-        x_validation: generic_data_type = None,
-        y_validation: generic_data_type = None,
+        x_validation: Optional[generic_data_type] = None,
+        y_validation: Optional[generic_data_type] = None,
         *,
         num_jobs: int = 4,
         num_retry: int = 4,
         num_search: Union[str, int, float] = 10,
-        score_weights: Union[Dict[str, float], None] = None,
+        score_weights: Optional[Dict[str, float]] = None,
         estimator_scoring_function: Union[str, scoring_fn_type] = "default",
         use_tqdm: bool = True,
         verbose_level: int = 2,
